//
//  Test_v3skew.h
//  BulletTest
//
//  Copyright (c) 2011 Apple Inc.
//

#ifndef BulletTest_Test_v3skew_h
#define BulletTest_Test_v3skew_h

#ifdef __cplusplus
extern "C"
{
#endif

	int Test_v3skew(void);

#ifdef __cplusplus
}
#endif

#endif
